# Discrete Bayes Module

The discrete_bayes module contains discrete Bayesian filter implementations.

::: bayesian_filters.discrete_bayes
    options:
      show_root_heading: true
      show_source: false
      members: true
